Read this in other language: [English](README.md), [Polski](README.pl.md).

**FULL Documentation currently available only in [Polish](README.pl.md).** English will soon be completed.

A module that gathers useful tools / scripts that makes life easier. Automates same things you can do every day.

TOC:

- [Requirements](#requirements)
- [Installation](#installation)
- [Configuration](#configuration)
- [Running](#running)
- [Tools and Scripts](#tools-and-scripts)
    - [Transfers](#transfers)
        - [Requirements](#requirements)
        - [Configuration](#configuration)
        - [Running](#running)
        - [Usage](#usage)
        - [User support](#user-support)
- [Help and Improvements](#help-and-improvements)
    
# Requirements

- Python 2.7.
- geckodriver.

# Installation

Install easylife:
```
pip install easylife
```

After installation et geckodriver:
```
sudo easylife get-geckodriver
```

If you have already geckodriver add it to PATH system environment or move to:
`/usr/bin` in case of OSX or Linux system.

# Configuration

# Running

```
easylife <tool>

e.g.:
easylife transfers
```

# Tools and Scripts

## Transfers

Currently supported bank's interfaces:
- mbank \(Polish version\) **https://www.mbank.pl/indywidualny/**

### Requirements

### Configuration

### Running

```
easylife transfers
```

### Usage

### User support

# Help and Improvements

If you have found some bugs, errors, something is not working as you want, something is not intuitive or something is missing and can be added or you just simply want to concribute then write to me: janiszewski.m.a@gmail.com.
Or make issue on GitHub.
Sometimes I check mails quite rarely but at least once per week ;)
